# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TotpCode(UniversalBaseModel):
    totp_identifier: str
    task_id: typing.Optional[str] = None
    workflow_id: typing.Optional[str] = None
    source: typing.Optional[str] = None
    content: str
    expired_at: typing.Optional[dt.datetime] = None
    totp_code_id: str
    code: str
    organization_id: str
    created_at: dt.datetime
    modified_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
